@@ -14,6 +14,11 @@ import aws_cdk.aws_iam
 import aws_cdk.aws_kms
 import aws_cdk.core
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-sns", "1.34.0", __name__[0:-6], "aws-sns@1.34.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
